@@ -97,6 +97,8 @@ AccountsController::AccountsController(QObject *parent)
         }
     });
 
+    connect(m_model, &UserModel::quickLoginVisibleChanged, this, &AccountsController::quickLoginVisibleChanged);
+
     QMetaObject::invokeMethod(m_worker, "active", Qt::QueuedConnection);
 }
 
@@ -133,7 +135,7 @@ QStringList AccountsController::avatars(const QString &id, const QString &filter
         return path1 < path2;
     });
 
-    if (filter.contains("icons/local") && !res.isEmpty()) {
+    if (filter.contains("icons/local")) {
         res.prepend("add"); // add button...
     }
 
@@ -365,7 +367,6 @@ void AccountsController::updateAllGroups()
     QList<User *> userList = m_model->userList();
     
     QStringList allGroupsList = allGroups();
-    int totalGroups = allGroupsList.size();
     
     for (const auto user : userList) {
         QString id = user->id();
