@@ -69,6 +69,9 @@ AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
         m_userModel->setAutoLoginVisable(true);
         m_userModel->setNoPassWordLoginVisable(false);
     }
+
+    m_userModel->setQuickLoginVisible(m_accountsInter->quickLoginEnabled());
+    connect(m_accountsInter, &AccountsDBusProxy::QuickLoginEnabledChanged, m_userModel, &UserModel::setQuickLoginVisible);
 }
 
 void AccountsWorker::getAllGroups()
@@ -322,7 +325,7 @@ void AccountsWorker::checkPwdLimitLevel(int level)
         return;
     }
     QDBusReply<int> pwdLimitLevel = interface.call("GetPwdLimitLevel");
-    if (pwdLimitLevel.error().type() == QDBusError::NoError && pwdLimitLevel > level) {
+    if (pwdLimitLevel.error().type() == QDBusError::NoError && pwdLimitLevel >= level) {
         QDBusReply<QString> errorTips = interface.call("GetPwdError");
         Q_EMIT showSafetyPage(errorTips);
     }
