@@ -4,7 +4,7 @@
 #include "commoninfomodel.h"
 
 #include <QDebug>
-#include <dtk5/DCore/DSysInfo>
+#include <DSysInfo>
 
 CommonInfoModel::CommonInfoModel(QObject *parent)
     : QObject(parent)
@@ -18,6 +18,7 @@ CommonInfoModel::CommonInfoModel(QObject *parent)
     , m_GrubAnimationModel(new GrubAnimationModel(this))
     , m_GrubMenuListModel(new GrubMenuListModel(this))
     , m_debugLogCurrentIndex(0)
+    , m_needShowModalDialog(false)
 {
 }
 
@@ -44,10 +45,8 @@ void CommonInfoModel::setShowGrubEditAuth(const bool enabled)
 
 void CommonInfoModel::setGrubEditAuthEnabled(const bool enabled)
 {
-    if (m_grubEditAuthEnabled != enabled) {
-        m_grubEditAuthEnabled = enabled;
-        Q_EMIT grubEditAuthEnabledChanged(m_grubEditAuthEnabled);
-    }
+    m_grubEditAuthEnabled = enabled;
+    Q_EMIT grubEditAuthEnabledChanged(m_grubEditAuthEnabled);
 }
 
 void CommonInfoModel::setDefaultEntry(const QString &entry)
@@ -151,6 +150,33 @@ void CommonInfoModel::setPlymouthTheme(const QString &themeName)
     Q_EMIT plymouthThemeChanged(themeName);
 }
 
+bool CommonInfoModel::isDeveloperMode() const
+{
+    return m_isDeveloperMode;
+}
+
+void CommonInfoModel::setIsDeveloperMode(bool newIsDeveloperMode)
+{
+    if (m_isDeveloperMode == newIsDeveloperMode)
+        return;
+    m_isDeveloperMode = newIsDeveloperMode;
+    emit isDeveloperModeChanged();
+}
+
+
+bool CommonInfoModel::needShowModalDialog() const
+{
+    return m_needShowModalDialog;
+}
+
+void CommonInfoModel::setNeedShowModalDialog(bool newNeedShowModalDialog)
+{
+    if (m_needShowModalDialog == newNeedShowModalDialog)
+        return;
+    m_needShowModalDialog = newNeedShowModalDialog;
+    emit needShowModalDialogChanged();
+}
+
 QString CommonInfoModel::grubThemePath() const
 {
     return m_grubThemePath;
@@ -158,8 +184,6 @@ QString CommonInfoModel::grubThemePath() const
 
 void CommonInfoModel::setGrubThemePath(const QString &newGrubThemePath)
 {
-    if (m_grubThemePath == newGrubThemePath)
-        return;
     m_grubThemePath = newGrubThemePath;
     emit grubThemePathChanged();
 }
