@@ -19,6 +19,7 @@
 #include <QCoreApplication>
 #include <QStringListModel>
 #include <QTimer>
+#include <QtQml/qqml.h>
 
 static installer::ZoneInfoList g_totalZones;
 
@@ -210,9 +211,9 @@ static QString translate(const QString &localeName, const QString &langRegion)
     }
 
     if (langRegions[0] == "Traditional Chinese" || langRegions[0] == "Simplified Chinese"
-        || langRegions[1] == QLocale::countryToString(QLocale::HongKong)
-        || langRegions[1] == QLocale::countryToString(QLocale::Macau)
-        || langRegions[1] == QLocale::countryToString(QLocale::Taiwan)) {
+        || langRegions[1] == QLocale::territoryToString(QLocale::HongKong)
+        || langRegions[1] == QLocale::territoryToString(QLocale::Macau)
+        || langRegions[1] == QLocale::territoryToString(QLocale::Taiwan)) {
 
         auto res = translateLangAndCountry(localeName);
         QString lang = res.value(0);
@@ -265,8 +266,9 @@ DatetimeModel::DatetimeModel(QObject *parent)
         m_work->setDigitGrouping(digitGrouping.replace(fmt1, fmt2));
     });
 
-    connect(this, &DatetimeModel::symbolChanged, this, [this](int format, const QString &symbol) {
-        if (format != CurrencySymbol && format != DigitGroupingSymbol)
+    connect(this, &DatetimeModel::symbolChanged, this, [this](int format) {
+        Q_EMIT numberExampleFormatChanged(numberExampleFormat());
+        if (format != CurrencySymbol && format != DigitGroupingSymbol && format != DecimalSymbol)
             return;
 
         Q_EMIT currentFormatChanged(format);
@@ -297,6 +299,8 @@ DatetimeModel::DatetimeModel(QObject *parent)
         Q_EMIT currentDateChanged();
     });
     timer->start();
+
+    qmlRegisterType<dccV25::ZoneInfoModel>("ZoneInfoModel", 1, 0, "ZoneInfoModel");
 }
 
 void DatetimeModel::setNTP(bool ntp)
@@ -598,7 +602,7 @@ void DatetimeModel::setRegion(const QString &region)
     }
     if (locale.language() != QLocale::C) {
         qDebug() << "set locale:" << locale.name();
-        QString country = locale.countryToString(locale.country());
+        QString country = locale.territoryToString(locale.territory());
         QString language = QLocale::languageToString(locale.language());
         QString langCountry = QString("%1:%2").arg(language).arg(country);
         m_work->setConfigValue(country_key, country);
@@ -662,7 +666,7 @@ void DatetimeModel::setCurrentLocaleAndLangRegion(const QString &localeName, con
     m_work->genLocale(locale.name());
 }
 
-QStringList DatetimeModel::availableFormats(int format)
+QStringList DatetimeModel::availableFormats(int format) const
 {
     QLocale locale(m_localeName);
     RegionAvailableData regionFormatsAvailable = RegionProxy::allTextData(locale);
@@ -732,7 +736,7 @@ QStringList DatetimeModel::availableFormats(int format)
     return QStringList();
 }
 
-int DatetimeModel::currentFormatIndex(int format)
+int DatetimeModel::currentFormatIndex(int format) const
 {
 #define INDEX_OF(format, MEMBER, isDate) { \
         const QDate CurrentDate(2024, 1, 1); \
@@ -1264,6 +1268,88 @@ int DatetimeModel::langState() const
     return m_langModel->getLangChangedState();
 }
 
+QString DatetimeModel::numberExampleFormat() const
+{
+    QString numberExampleFormat = tr("Example") + ":";
+
+    QStringList digitGroupingValues = availableFormats(DigitGrouping);
+    int digitGroupingIndex = currentFormatIndex(DigitGrouping);
+    if (!digitGroupingValues.isEmpty() && (digitGroupingIndex < 0 || digitGroupingIndex >= digitGroupingValues.size())) {
+        digitGroupingIndex = 0;
+    }
+    QStringList decimalValues = availableFormats(DecimalSymbol);
+    int decimalIndex = currentFormatIndex(DecimalSymbol);
+    if (!decimalValues.isEmpty() && (decimalIndex < 0 || decimalIndex >= decimalValues.size())) {
+        decimalIndex = 0;
+    }
+    QStringList currencyValues = availableFormats(CurrencySymbol);
+    int currencyIndex = currentFormatIndex(CurrencySymbol);
+    if (!currencyValues.isEmpty() && (currencyIndex < 0 || currencyIndex >= currencyValues.size())) {
+        currencyIndex = 0;
+    }
+
+    QString numberData;
+    if (digitGroupingIndex >= 0 && digitGroupingIndex < digitGroupingValues.size() &&
+        decimalIndex >= 0 && decimalIndex < decimalValues.size() &&
+        currencyIndex >= 0 && currencyIndex < currencyValues.size()) {
+
+        numberData += digitGroupingValues.at(digitGroupingIndex);
+        numberData += normalizeSpace(decimalValues.at(decimalIndex));
+        numberData += "00";
+
+        QString currencyFormat = currencyValues.at(currencyIndex);
+        int positiveCurrencyIndex = currentFormatIndex(PositiveCurrency);
+        QString positiveCurrencyFormat;
+        switch (positiveCurrencyIndex) {
+        case 0://¥1.1
+            positiveCurrencyFormat = QString("%1%2").arg(currencyFormat).arg(numberData);
+            break;
+        case 1://1.1¥
+            positiveCurrencyFormat = QString("%1%2").arg(numberData).arg(currencyFormat);
+            break;
+        case 2://¥ 1.1
+            positiveCurrencyFormat = QString("%1 %2").arg(currencyFormat).arg(numberData);
+            break;
+        case 3://1.1 ¥
+            positiveCurrencyFormat = QString("%1 %2").arg(numberData).arg(currencyFormat);
+            break;
+        default:
+            break;
+        }
+
+        int negativeCurrencyIndex = currentFormatIndex(NegativeCurrency);
+        QString negativeCurrency;
+        switch (negativeCurrencyIndex) {
+        case 0://-¥1.1
+            negativeCurrency = QString("%1%2%3").arg("-").arg(currencyFormat).arg(numberData);
+            break;
+        case 1://¥-1.1
+            negativeCurrency = QString("%1%2%3").arg(currencyFormat).arg("-").arg(numberData);
+            break;
+        case 2://¥1.1-
+            negativeCurrency = QString("%1%2%3").arg(currencyFormat).arg(numberData).arg("-");
+            break;
+        case 3://-1.1¥
+            negativeCurrency = QString("%1%2%3").arg("-").arg(numberData).arg(currencyFormat);
+            break;
+        case 4://1.1-¥
+            negativeCurrency = QString("%1%2%3").arg(numberData).arg("-").arg(currencyFormat);
+            break;
+        case 5://1.1¥-
+            negativeCurrency = QString("%1%2%3").arg(numberData).arg(currencyFormat).arg("-");
+            break;
+        default:
+            break;
+        }
+
+        numberExampleFormat = numberExampleFormat + "  " + positiveCurrencyFormat + "  " + negativeCurrency;
+    } else {
+        numberExampleFormat.clear();
+    }
+
+    return numberExampleFormat;
+}
+
 DCC_FACTORY_CLASS(DatetimeModel)
 
 #include "datetimemodel.moc"
