@@ -51,17 +51,21 @@ class SoundModel : public QObject
     Q_PROPERTY(QStringList bluetoothModeOpts READ bluetoothAudioModeOpts NOTIFY bluetoothModeOptsChanged FINAL)
     Q_PROPERTY(QString currentBluetoothAudioMode READ currentBluetoothAudioMode NOTIFY bluetoothModeChanged FINAL)
     Q_PROPERTY(bool showBluetoothMode READ showBluetoothMode NOTIFY showBluetoothModeChanged FINAL)
+    Q_PROPERTY(bool showInputBluetoothMode READ showInputBluetoothMode NOTIFY showInputBluetoothModeChanged FINAL)
 
     Q_PROPERTY(bool outPutPortComboEnable READ outPutPortComboEnable NOTIFY outPutPortComboEnableChanged FINAL)
     Q_PROPERTY(bool inPutPortComboEnable READ inPutPortComboEnable NOTIFY inPutPortComboEnableChanged FINAL)
 
+    Q_PROPERTY(bool speakerOn READ speakerOn NOTIFY speakerOnChanged FINAL)
+    Q_PROPERTY(bool microphoneOn READ microphoneOn NOTIFY microphoneOnChanged FINAL)
+
     QML_NAMED_ELEMENT(SoundModel)
     QML_SINGLETON
 public:
     explicit SoundModel(QObject *parent = 0);
     ~SoundModel();
 
-    inline bool speakerOn() const { return m_speakerOn; }
+    bool speakerOn() const { return m_speakerOn; }
     void setSpeakerOn(bool speakerOn);
 
     inline bool isPortEnable() const { return m_portEnable; }
@@ -164,22 +168,19 @@ public:
 
     // 初始化输入设备ui数据
     void initSoundDeviceModel(Port::Direction direction);
-    SoundDeviceData* getSoundDeviceData(int index, int portType);
+    Port* getSoundDeviceData(int index, int portType);
     void updateSoundDeviceModel(Port* port);
+    void updateAllDeviceModel();
+    void updateActiveComboIndex();
 
     int outPutPortComboIndex() const;
     void setOutPutPortComboIndex(int newOutPutPortComboIndex);
-    Port *activeOutPutPort() const;
-    void setActiveOutPutPort(Port *newActiveOutPutPort);
     QStringList inPutPortCombo() const;
     void setInPutPortCombo(const QStringList &newInPutPortCombo);
     int inPutPortComboIndex() const;
     void setInPutPortComboIndex(int newInPutPortComboIndex);
-    Port *activeinPutPort() const;
-    void setActiveinPutPort(Port *newActiveinPutPort);
 
     void updatePortCombo();
-    Port* getPortForComboIndex(int index, int portType);
 
     Q_INVOKABLE SoundEffectsModel* soundEffectsModel() const;
     Q_INVOKABLE QString getListName(int index) const;
@@ -212,6 +213,9 @@ public:
     bool inPutPortComboEnable() const;
     void setInPutPortComboEnable(bool newInPutPortComboEnable);
 
+    bool showInputBluetoothMode() const;
+    void setShowInputBluetoothMode(bool newShowInputBluetoothMode);
+
 private:
 
 
@@ -275,6 +279,8 @@ Q_SIGNALS:
 
     void inPutPortComboEnableChanged();
 
+    void showInputBluetoothModeChanged();
+
 private:
     QString m_audioServer;     // 当前使用音频框架
     bool m_audioServerStatus{true};  // 设置音频时的状态
@@ -316,12 +322,10 @@ private:
 
     QStringList m_outPutPortCombo;
     int m_outPutPortComboIndex;
-    Port* m_activeOutPutPort;
     bool m_outPutPortComboEnable;
 
     QStringList m_inPutPortCombo;
     int m_inPutPortComboIndex;
-    Port* m_activeinPutPort;
     bool m_inPutPortComboEnable;
 
     SoundEffectsModel* m_soundEffectsModel;
@@ -334,6 +338,7 @@ private:
 
     bool m_audioMono;
     bool m_showBluetoothMode;
+    bool m_showInputBluetoothMode;
 };
 
 #endif // DCC_SOUND_SOUNDMODEL_H
