@@ -394,9 +394,12 @@ void SoundWorker::cardsChanged(const QString &cards)
 
                 port->setIsActive(isActiveInputPort || isActiveOuputPort);
 
-                if (port->isActive()) {
+                if (isActiveOuputPort) {
                     m_model->setShowBluetoothMode(port->isBluetoothPort());
                 }
+                if (isActiveInputPort) {
+                    m_model->setShowInputBluetoothMode(port->isBluetoothPort());
+                }
                 if (!include) { m_model->addPort(port); }
 
                 tmpPorts << portId;
@@ -516,6 +519,9 @@ void SoundWorker::updatePortActivity()
         if (isActiveOuputPort) {
             m_model->setShowBluetoothMode(port->isBluetoothPort());
         }
+        if (isActiveInputPort) {
+            m_model->setShowInputBluetoothMode(port->isBluetoothPort());
+        }
     }
     m_model->updateActiveComboIndex();
 }
